@@ -147,7 +147,7 @@ eval.desc <- function(molecules, which.desc, verbose = FALSE) {
       vals <- lapply(descvals, .get.desc.values, nexpected = length(dnames))
       vals <- data.frame(do.call('rbind', vals))
 
-      if (length(vals) == 1 && is.na(vals)) {
+      if (length(vals) == 1 && any(is.na(vals))) {
         vals <- as.data.frame(matrix(NA, nrow=1, ncol=length(dnames)))
       }
       
